@@ -7,7 +7,7 @@ RDF::Trine::Serializer - RDF Serializer class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer version 0.999_01
+This document describes RDF::Trine::Serializer version 0.999_02
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ our %serializer_names;
 our %format_uris;
 our %media_types;
 BEGIN {
-	$VERSION	= '0.999_01';
+	$VERSION	= '0.999_02';
 }
 
 use RDF::Trine::Serializer::NQuads;
@@ -90,12 +90,17 @@ sub new {
 =item C<< negotiate ( request_headers => $request_headers, %options ) >>
 
 Returns a two-element list containing an appropriate media type and
-RDF::Trine::Serializer object as decided by L<HTTP::Negotiate>.
-If the C<< 'request_headers' >> key-value is supplied, the
-C<< $request_headers >> is passed to C<< HTTP::Negotiate::choose >>.
-The option C<< 'restrict' >>, set to a list of serializer names, can be 
-used to limit the serializers to choose from. The rest of 
-C<< %options >> is passed through to the serializer constructor.
+RDF::Trine::Serializer object as decided by L<HTTP::Negotiate>.  If
+the C<< 'request_headers' >> key-value is supplied, the C<<
+$request_headers >> is passed to C<< HTTP::Negotiate::choose >>.  The
+option C<< 'restrict' >>, set to a list of serializer names, can be
+used to limit the serializers to choose from. Finally, an C<<'extends' >> 
+option can be set to a hashref that contains MIME-types
+as keys and a custom variant as value. This will enable the user to
+use this negotiator to return a type that isn't supported by any
+serializers. The subsequent code will have to find out how to return a
+representation. The rest of C<< %options >> is passed through to the
+serializer constructor.
 
 =cut
 
